from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import Literal, cast






T = TypeVar("T", bound="GetByOrgByRepoContentResponse200Type2EntriesItemType1")



@_attrs_define
class GetByOrgByRepoContentResponse200Type2EntriesItemType1:
    """ 
        Attributes:
            type_ (Literal['symlink']):
            name (str):
            path (str):
            sha (str):
            size (float):
            mode (int):
     """

    type_: Literal['symlink']
    name: str
    path: str
    sha: str
    size: float
    mode: int
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        type_ = self.type_

        name = self.name

        path = self.path

        sha = self.sha

        size = self.size

        mode = self.mode


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "type": type_,
            "name": name,
            "path": path,
            "sha": sha,
            "size": size,
            "mode": mode,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        type_ = cast(Literal['symlink'] , d.pop("type"))
        if type_ != 'symlink':
            raise ValueError(f"type must match const 'symlink', got '{type_}'")

        name = d.pop("name")

        path = d.pop("path")

        sha = d.pop("sha")

        size = d.pop("size")

        mode = d.pop("mode")

        get_by_org_by_repo_content_response_200_type_2_entries_item_type_1 = cls(
            type_=type_,
            name=name,
            path=path,
            sha=sha,
            size=size,
            mode=mode,
        )


        get_by_org_by_repo_content_response_200_type_2_entries_item_type_1.additional_properties = d
        return get_by_org_by_repo_content_response_200_type_2_entries_item_type_1

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.post_by_org_repo_response_400_error import PostByOrgRepoResponse400Error





T = TypeVar("T", bound="PostByOrgRepoResponse400")



@_attrs_define
class PostByOrgRepoResponse400:
    """ 
        Attributes:
            error (PostByOrgRepoResponse400Error):
     """

    error: PostByOrgRepoResponse400Error
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.post_by_org_repo_response_400_error import PostByOrgRepoResponse400Error
        error = self.error.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "error": error,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.post_by_org_repo_response_400_error import PostByOrgRepoResponse400Error
        d = dict(src_dict)
        error = PostByOrgRepoResponse400Error.from_dict(d.pop("error"))




        post_by_org_repo_response_400 = cls(
            error=error,
        )


        post_by_org_repo_response_400.additional_properties = d
        return post_by_org_repo_response_400

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.post_by_org_repo_bulk_tags_body import PostByOrgRepoBulkTagsBody
from ...models.post_by_org_repo_bulk_tags_response_200 import PostByOrgRepoBulkTagsResponse200
from ...models.post_by_org_repo_bulk_tags_response_400 import PostByOrgRepoBulkTagsResponse400
from ...models.post_by_org_repo_bulk_tags_response_401 import PostByOrgRepoBulkTagsResponse401
from ...models.post_by_org_repo_bulk_tags_response_403 import PostByOrgRepoBulkTagsResponse403
from ...models.post_by_org_repo_bulk_tags_response_404 import PostByOrgRepoBulkTagsResponse404
from ...models.post_by_org_repo_bulk_tags_response_406 import PostByOrgRepoBulkTagsResponse406
from ...models.post_by_org_repo_bulk_tags_response_409 import PostByOrgRepoBulkTagsResponse409
from ...models.post_by_org_repo_bulk_tags_response_500 import PostByOrgRepoBulkTagsResponse500
from typing import cast



def _get_kwargs(
    org: str,
    *,
    body: PostByOrgRepoBulkTagsBody,

) -> dict[str, Any]:
    headers: dict[str, Any] = {}


    

    

    _kwargs: dict[str, Any] = {
        "method": "post",
        "url": "/{org}/repo/bulk/tags".format(org=quote(str(org), safe=""),),
    }

    _kwargs["json"] = body.to_dict()


    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500 | None:
    if response.status_code == 200:
        response_200 = PostByOrgRepoBulkTagsResponse200.from_dict(response.json())



        return response_200

    if response.status_code == 400:
        response_400 = PostByOrgRepoBulkTagsResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = PostByOrgRepoBulkTagsResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 403:
        response_403 = PostByOrgRepoBulkTagsResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = PostByOrgRepoBulkTagsResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 406:
        response_406 = PostByOrgRepoBulkTagsResponse406.from_dict(response.json())



        return response_406

    if response.status_code == 409:
        response_409 = PostByOrgRepoBulkTagsResponse409.from_dict(response.json())



        return response_409

    if response.status_code == 500:
        response_500 = PostByOrgRepoBulkTagsResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    body: PostByOrgRepoBulkTagsBody,

) -> Response[PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500]:
    """ Bulk update Tags

     Bulk set or remove repo tags

    Args:
        org (str):
        body (PostByOrgRepoBulkTagsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    body: PostByOrgRepoBulkTagsBody,

) -> PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500 | None:
    """ Bulk update Tags

     Bulk set or remove repo tags

    Args:
        org (str):
        body (PostByOrgRepoBulkTagsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500
     """


    return sync_detailed(
        org=org,
client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    body: PostByOrgRepoBulkTagsBody,

) -> Response[PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500]:
    """ Bulk update Tags

     Bulk set or remove repo tags

    Args:
        org (str):
        body (PostByOrgRepoBulkTagsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    org: str,
    *,
    client: AuthenticatedClient | Client,
    body: PostByOrgRepoBulkTagsBody,

) -> PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500 | None:
    """ Bulk update Tags

     Bulk set or remove repo tags

    Args:
        org (str):
        body (PostByOrgRepoBulkTagsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PostByOrgRepoBulkTagsResponse200 | PostByOrgRepoBulkTagsResponse400 | PostByOrgRepoBulkTagsResponse401 | PostByOrgRepoBulkTagsResponse403 | PostByOrgRepoBulkTagsResponse404 | PostByOrgRepoBulkTagsResponse406 | PostByOrgRepoBulkTagsResponse409 | PostByOrgRepoBulkTagsResponse500
     """


    return (await asyncio_detailed(
        org=org,
client=client,
body=body,

    )).parsed



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.get_by_org_by_repo_diff_response_406_error_details import GetByOrgByRepoDiffResponse406ErrorDetails





T = TypeVar("T", bound="GetByOrgByRepoDiffResponse406Error")



@_attrs_define
class GetByOrgByRepoDiffResponse406Error:
    """ 
        Attributes:
            code (str):
            message (str):
            details (GetByOrgByRepoDiffResponse406ErrorDetails | Unset):
     """

    code: str
    message: str
    details: GetByOrgByRepoDiffResponse406ErrorDetails | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_by_org_by_repo_diff_response_406_error_details import GetByOrgByRepoDiffResponse406ErrorDetails
        code = self.code

        message = self.message

        details: dict[str, Any] | Unset = UNSET
        if not isinstance(self.details, Unset):
            details = self.details.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "code": code,
            "message": message,
        })
        if details is not UNSET:
            field_dict["details"] = details

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_by_org_by_repo_diff_response_406_error_details import GetByOrgByRepoDiffResponse406ErrorDetails
        d = dict(src_dict)
        code = d.pop("code")

        message = d.pop("message")

        _details = d.pop("details", UNSET)
        details: GetByOrgByRepoDiffResponse406ErrorDetails | Unset
        if isinstance(_details,  Unset):
            details = UNSET
        else:
            details = GetByOrgByRepoDiffResponse406ErrorDetails.from_dict(_details)




        get_by_org_by_repo_diff_response_406_error = cls(
            code=code,
            message=message,
            details=details,
        )


        get_by_org_by_repo_diff_response_406_error.additional_properties = d
        return get_by_org_by_repo_diff_response_406_error

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.get_by_org_by_repo_content_response_200_type_0 import GetByOrgByRepoContentResponse200Type0
from ...models.get_by_org_by_repo_content_response_200_type_1 import GetByOrgByRepoContentResponse200Type1
from ...models.get_by_org_by_repo_content_response_200_type_2 import GetByOrgByRepoContentResponse200Type2
from ...models.get_by_org_by_repo_content_response_400 import GetByOrgByRepoContentResponse400
from ...models.get_by_org_by_repo_content_response_401 import GetByOrgByRepoContentResponse401
from ...models.get_by_org_by_repo_content_response_403 import GetByOrgByRepoContentResponse403
from ...models.get_by_org_by_repo_content_response_404 import GetByOrgByRepoContentResponse404
from ...models.get_by_org_by_repo_content_response_406 import GetByOrgByRepoContentResponse406
from ...models.get_by_org_by_repo_content_response_409 import GetByOrgByRepoContentResponse409
from ...models.get_by_org_by_repo_content_response_500 import GetByOrgByRepoContentResponse500
from ...types import UNSET, Unset
from typing import cast



def _get_kwargs(
    org: str,
    repo: str,
    *,
    oid: str | Unset = UNSET,
    path: str | Unset = UNSET,
    depth: int | Unset = UNSET,

) -> dict[str, Any]:
    

    

    params: dict[str, Any] = {}

    params["oid"] = oid

    params["path"] = path

    params["depth"] = depth


    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}


    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/{org}/{repo}/content".format(org=quote(str(org), safe=""),repo=quote(str(repo), safe=""),),
        "params": params,
    }


    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500 | None:
    if response.status_code == 200:
        def _parse_response_200(data: object) -> GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2:
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                response_200_type_0 = GetByOrgByRepoContentResponse200Type0.from_dict(data)



                return response_200_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                response_200_type_1 = GetByOrgByRepoContentResponse200Type1.from_dict(data)



                return response_200_type_1
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            if not isinstance(data, dict):
                raise TypeError()
            response_200_type_2 = GetByOrgByRepoContentResponse200Type2.from_dict(data)



            return response_200_type_2

        response_200 = _parse_response_200(response.json())

        return response_200

    if response.status_code == 400:
        response_400 = GetByOrgByRepoContentResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = GetByOrgByRepoContentResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 403:
        response_403 = GetByOrgByRepoContentResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = GetByOrgByRepoContentResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 406:
        response_406 = GetByOrgByRepoContentResponse406.from_dict(response.json())



        return response_406

    if response.status_code == 409:
        response_409 = GetByOrgByRepoContentResponse409.from_dict(response.json())



        return response_409

    if response.status_code == 500:
        response_500 = GetByOrgByRepoContentResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    oid: str | Unset = UNSET,
    path: str | Unset = UNSET,
    depth: int | Unset = UNSET,

) -> Response[GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500]:
    """ Get content

     Get file content or directory listing at a path. Use Accept: application/json for the JSON union
    response, or Accept: application/octet-stream for raw file bytes. Directory + octet-stream requests
    return 406 Not Acceptable.

    Args:
        org (str):
        repo (str):
        oid (str | Unset):
        path (str | Unset):
        depth (int | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
repo=repo,
oid=oid,
path=path,
depth=depth,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    oid: str | Unset = UNSET,
    path: str | Unset = UNSET,
    depth: int | Unset = UNSET,

) -> GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500 | None:
    """ Get content

     Get file content or directory listing at a path. Use Accept: application/json for the JSON union
    response, or Accept: application/octet-stream for raw file bytes. Directory + octet-stream requests
    return 406 Not Acceptable.

    Args:
        org (str):
        repo (str):
        oid (str | Unset):
        path (str | Unset):
        depth (int | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500
     """


    return sync_detailed(
        org=org,
repo=repo,
client=client,
oid=oid,
path=path,
depth=depth,

    ).parsed

async def asyncio_detailed(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    oid: str | Unset = UNSET,
    path: str | Unset = UNSET,
    depth: int | Unset = UNSET,

) -> Response[GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500]:
    """ Get content

     Get file content or directory listing at a path. Use Accept: application/json for the JSON union
    response, or Accept: application/octet-stream for raw file bytes. Directory + octet-stream requests
    return 406 Not Acceptable.

    Args:
        org (str):
        repo (str):
        oid (str | Unset):
        path (str | Unset):
        depth (int | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
repo=repo,
oid=oid,
path=path,
depth=depth,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    oid: str | Unset = UNSET,
    path: str | Unset = UNSET,
    depth: int | Unset = UNSET,

) -> GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500 | None:
    """ Get content

     Get file content or directory listing at a path. Use Accept: application/json for the JSON union
    response, or Accept: application/octet-stream for raw file bytes. Directory + octet-stream requests
    return 406 Not Acceptable.

    Args:
        org (str):
        repo (str):
        oid (str | Unset):
        path (str | Unset):
        depth (int | Unset):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetByOrgByRepoContentResponse200Type0 | GetByOrgByRepoContentResponse200Type1 | GetByOrgByRepoContentResponse200Type2 | GetByOrgByRepoContentResponse400 | GetByOrgByRepoContentResponse401 | GetByOrgByRepoContentResponse403 | GetByOrgByRepoContentResponse404 | GetByOrgByRepoContentResponse406 | GetByOrgByRepoContentResponse409 | GetByOrgByRepoContentResponse500
     """


    return (await asyncio_detailed(
        org=org,
repo=repo,
client=client,
oid=oid,
path=path,
depth=depth,

    )).parsed



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.patch_by_org_by_repo_body import PatchByOrgByRepoBody
from ...models.patch_by_org_by_repo_response_200 import PatchByOrgByRepoResponse200
from ...models.patch_by_org_by_repo_response_400 import PatchByOrgByRepoResponse400
from ...models.patch_by_org_by_repo_response_401 import PatchByOrgByRepoResponse401
from ...models.patch_by_org_by_repo_response_403 import PatchByOrgByRepoResponse403
from ...models.patch_by_org_by_repo_response_404 import PatchByOrgByRepoResponse404
from ...models.patch_by_org_by_repo_response_406 import PatchByOrgByRepoResponse406
from ...models.patch_by_org_by_repo_response_409 import PatchByOrgByRepoResponse409
from ...models.patch_by_org_by_repo_response_500 import PatchByOrgByRepoResponse500
from typing import cast



def _get_kwargs(
    org: str,
    repo: str,
    *,
    body: PatchByOrgByRepoBody,

) -> dict[str, Any]:
    headers: dict[str, Any] = {}


    

    

    _kwargs: dict[str, Any] = {
        "method": "patch",
        "url": "/{org}/{repo}".format(org=quote(str(org), safe=""),repo=quote(str(repo), safe=""),),
    }

    _kwargs["json"] = body.to_dict()


    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500 | None:
    if response.status_code == 200:
        response_200 = PatchByOrgByRepoResponse200.from_dict(response.json())



        return response_200

    if response.status_code == 400:
        response_400 = PatchByOrgByRepoResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = PatchByOrgByRepoResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 403:
        response_403 = PatchByOrgByRepoResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = PatchByOrgByRepoResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 406:
        response_406 = PatchByOrgByRepoResponse406.from_dict(response.json())



        return response_406

    if response.status_code == 409:
        response_409 = PatchByOrgByRepoResponse409.from_dict(response.json())



        return response_409

    if response.status_code == 500:
        response_500 = PatchByOrgByRepoResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    body: PatchByOrgByRepoBody,

) -> Response[PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500]:
    """ Update repository

     Update repository name, default branch, tags, or upstream configuration. Tags are patched: set
    values to add/update and null values to remove.

    Args:
        org (str):
        repo (str):
        body (PatchByOrgByRepoBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
repo=repo,
body=body,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    body: PatchByOrgByRepoBody,

) -> PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500 | None:
    """ Update repository

     Update repository name, default branch, tags, or upstream configuration. Tags are patched: set
    values to add/update and null values to remove.

    Args:
        org (str):
        repo (str):
        body (PatchByOrgByRepoBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500
     """


    return sync_detailed(
        org=org,
repo=repo,
client=client,
body=body,

    ).parsed

async def asyncio_detailed(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    body: PatchByOrgByRepoBody,

) -> Response[PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500]:
    """ Update repository

     Update repository name, default branch, tags, or upstream configuration. Tags are patched: set
    values to add/update and null values to remove.

    Args:
        org (str):
        repo (str):
        body (PatchByOrgByRepoBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
repo=repo,
body=body,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    body: PatchByOrgByRepoBody,

) -> PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500 | None:
    """ Update repository

     Update repository name, default branch, tags, or upstream configuration. Tags are patched: set
    values to add/update and null values to remove.

    Args:
        org (str):
        repo (str):
        body (PatchByOrgByRepoBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        PatchByOrgByRepoResponse200 | PatchByOrgByRepoResponse400 | PatchByOrgByRepoResponse401 | PatchByOrgByRepoResponse403 | PatchByOrgByRepoResponse404 | PatchByOrgByRepoResponse406 | PatchByOrgByRepoResponse409 | PatchByOrgByRepoResponse500
     """


    return (await asyncio_detailed(
        org=org,
repo=repo,
client=client,
body=body,

    )).parsed



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_by_org_by_repo_diff_response_200_files_item import GetByOrgByRepoDiffResponse200FilesItem
  from ..models.get_by_org_by_repo_diff_response_200_filtered_files_item import GetByOrgByRepoDiffResponse200FilteredFilesItem
  from ..models.get_by_org_by_repo_diff_response_200_stats import GetByOrgByRepoDiffResponse200Stats





T = TypeVar("T", bound="GetByOrgByRepoDiffResponse200")



@_attrs_define
class GetByOrgByRepoDiffResponse200:
    """ 
        Attributes:
            base (str):
            head (str):
            truncated (bool):
            stats (GetByOrgByRepoDiffResponse200Stats):
            files (list[GetByOrgByRepoDiffResponse200FilesItem]):
            filtered_files (list[GetByOrgByRepoDiffResponse200FilteredFilesItem]):
     """

    base: str
    head: str
    truncated: bool
    stats: GetByOrgByRepoDiffResponse200Stats
    files: list[GetByOrgByRepoDiffResponse200FilesItem]
    filtered_files: list[GetByOrgByRepoDiffResponse200FilteredFilesItem]
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_by_org_by_repo_diff_response_200_stats import GetByOrgByRepoDiffResponse200Stats
        from ..models.get_by_org_by_repo_diff_response_200_files_item import GetByOrgByRepoDiffResponse200FilesItem
        from ..models.get_by_org_by_repo_diff_response_200_filtered_files_item import GetByOrgByRepoDiffResponse200FilteredFilesItem
        base = self.base

        head = self.head

        truncated = self.truncated

        stats = self.stats.to_dict()

        files = []
        for files_item_data in self.files:
            files_item = files_item_data.to_dict()
            files.append(files_item)



        filtered_files = []
        for filtered_files_item_data in self.filtered_files:
            filtered_files_item = filtered_files_item_data.to_dict()
            filtered_files.append(filtered_files_item)




        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "base": base,
            "head": head,
            "truncated": truncated,
            "stats": stats,
            "files": files,
            "filtered_files": filtered_files,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_by_org_by_repo_diff_response_200_files_item import GetByOrgByRepoDiffResponse200FilesItem
        from ..models.get_by_org_by_repo_diff_response_200_filtered_files_item import GetByOrgByRepoDiffResponse200FilteredFilesItem
        from ..models.get_by_org_by_repo_diff_response_200_stats import GetByOrgByRepoDiffResponse200Stats
        d = dict(src_dict)
        base = d.pop("base")

        head = d.pop("head")

        truncated = d.pop("truncated")

        stats = GetByOrgByRepoDiffResponse200Stats.from_dict(d.pop("stats"))




        files = []
        _files = d.pop("files")
        for files_item_data in (_files):
            files_item = GetByOrgByRepoDiffResponse200FilesItem.from_dict(files_item_data)



            files.append(files_item)


        filtered_files = []
        _filtered_files = d.pop("filtered_files")
        for filtered_files_item_data in (_filtered_files):
            filtered_files_item = GetByOrgByRepoDiffResponse200FilteredFilesItem.from_dict(filtered_files_item_data)



            filtered_files.append(filtered_files_item)


        get_by_org_by_repo_diff_response_200 = cls(
            base=base,
            head=head,
            truncated=truncated,
            stats=stats,
            files=files,
            filtered_files=filtered_files,
        )


        get_by_org_by_repo_diff_response_200.additional_properties = d
        return get_by_org_by_repo_diff_response_200

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_by_org_by_repo_response_200_tags import GetByOrgByRepoResponse200Tags
  from ..models.get_by_org_by_repo_response_200_upstream_type_0 import GetByOrgByRepoResponse200UpstreamType0





T = TypeVar("T", bound="GetByOrgByRepoResponse200")



@_attrs_define
class GetByOrgByRepoResponse200:
    """ 
        Attributes:
            id (str):
            org (str):
            name (str):
            default_branch (str):
            head_oid (None | str):
            created_at (str):
            tags (GetByOrgByRepoResponse200Tags):
            upstream (GetByOrgByRepoResponse200UpstreamType0 | None): Optionally add an upstream repository. You can
                configure automatic syncing from the upstream repository.
     """

    id: str
    org: str
    name: str
    default_branch: str
    head_oid: None | str
    created_at: str
    tags: GetByOrgByRepoResponse200Tags
    upstream: GetByOrgByRepoResponse200UpstreamType0 | None
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_by_org_by_repo_response_200_tags import GetByOrgByRepoResponse200Tags
        from ..models.get_by_org_by_repo_response_200_upstream_type_0 import GetByOrgByRepoResponse200UpstreamType0
        id = self.id

        org = self.org

        name = self.name

        default_branch = self.default_branch

        head_oid: None | str
        head_oid = self.head_oid

        created_at = self.created_at

        tags = self.tags.to_dict()

        upstream: dict[str, Any] | None
        if isinstance(self.upstream, GetByOrgByRepoResponse200UpstreamType0):
            upstream = self.upstream.to_dict()
        else:
            upstream = self.upstream


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "id": id,
            "org": org,
            "name": name,
            "default_branch": default_branch,
            "head_oid": head_oid,
            "created_at": created_at,
            "tags": tags,
            "upstream": upstream,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_by_org_by_repo_response_200_tags import GetByOrgByRepoResponse200Tags
        from ..models.get_by_org_by_repo_response_200_upstream_type_0 import GetByOrgByRepoResponse200UpstreamType0
        d = dict(src_dict)
        id = d.pop("id")

        org = d.pop("org")

        name = d.pop("name")

        default_branch = d.pop("default_branch")

        def _parse_head_oid(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        head_oid = _parse_head_oid(d.pop("head_oid"))


        created_at = d.pop("created_at")

        tags = GetByOrgByRepoResponse200Tags.from_dict(d.pop("tags"))




        def _parse_upstream(data: object) -> GetByOrgByRepoResponse200UpstreamType0 | None:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                upstream_type_0 = GetByOrgByRepoResponse200UpstreamType0.from_dict(data)



                return upstream_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(GetByOrgByRepoResponse200UpstreamType0 | None, data)

        upstream = _parse_upstream(d.pop("upstream"))


        get_by_org_by_repo_response_200 = cls(
            id=id,
            org=org,
            name=name,
            default_branch=default_branch,
            head_oid=head_oid,
            created_at=created_at,
            tags=tags,
            upstream=upstream,
        )


        get_by_org_by_repo_response_200.additional_properties = d
        return get_by_org_by_repo_response_200

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from http import HTTPStatus
from typing import Any, cast
from urllib.parse import quote

import httpx

from ...client import AuthenticatedClient, Client
from ...types import Response, UNSET
from ... import errors

from ...models.get_by_org_by_repo_diff_response_200 import GetByOrgByRepoDiffResponse200
from ...models.get_by_org_by_repo_diff_response_400 import GetByOrgByRepoDiffResponse400
from ...models.get_by_org_by_repo_diff_response_401 import GetByOrgByRepoDiffResponse401
from ...models.get_by_org_by_repo_diff_response_403 import GetByOrgByRepoDiffResponse403
from ...models.get_by_org_by_repo_diff_response_404 import GetByOrgByRepoDiffResponse404
from ...models.get_by_org_by_repo_diff_response_406 import GetByOrgByRepoDiffResponse406
from ...models.get_by_org_by_repo_diff_response_409 import GetByOrgByRepoDiffResponse409
from ...models.get_by_org_by_repo_diff_response_500 import GetByOrgByRepoDiffResponse500
from typing import cast



def _get_kwargs(
    org: str,
    repo: str,
    *,
    base: str,
    head: str,

) -> dict[str, Any]:
    

    

    params: dict[str, Any] = {}

    params["base"] = base

    params["head"] = head


    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}


    _kwargs: dict[str, Any] = {
        "method": "get",
        "url": "/{org}/{repo}/diff".format(org=quote(str(org), safe=""),repo=quote(str(repo), safe=""),),
        "params": params,
    }


    return _kwargs



def _parse_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500 | None:
    if response.status_code == 200:
        response_200 = GetByOrgByRepoDiffResponse200.from_dict(response.json())



        return response_200

    if response.status_code == 400:
        response_400 = GetByOrgByRepoDiffResponse400.from_dict(response.json())



        return response_400

    if response.status_code == 401:
        response_401 = GetByOrgByRepoDiffResponse401.from_dict(response.json())



        return response_401

    if response.status_code == 403:
        response_403 = GetByOrgByRepoDiffResponse403.from_dict(response.json())



        return response_403

    if response.status_code == 404:
        response_404 = GetByOrgByRepoDiffResponse404.from_dict(response.json())



        return response_404

    if response.status_code == 406:
        response_406 = GetByOrgByRepoDiffResponse406.from_dict(response.json())



        return response_406

    if response.status_code == 409:
        response_409 = GetByOrgByRepoDiffResponse409.from_dict(response.json())



        return response_409

    if response.status_code == 500:
        response_500 = GetByOrgByRepoDiffResponse500.from_dict(response.json())



        return response_500

    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(*, client: AuthenticatedClient | Client, response: httpx.Response) -> Response[GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    base: str,
    head: str,

) -> Response[GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500]:
    """ Get diff

     Retrieve the diff between two commit OIDs

    Args:
        org (str):
        repo (str):
        base (str):
        head (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
repo=repo,
base=base,
head=head,

    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)

def sync(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    base: str,
    head: str,

) -> GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500 | None:
    """ Get diff

     Retrieve the diff between two commit OIDs

    Args:
        org (str):
        repo (str):
        base (str):
        head (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500
     """


    return sync_detailed(
        org=org,
repo=repo,
client=client,
base=base,
head=head,

    ).parsed

async def asyncio_detailed(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    base: str,
    head: str,

) -> Response[GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500]:
    """ Get diff

     Retrieve the diff between two commit OIDs

    Args:
        org (str):
        repo (str):
        base (str):
        head (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500]
     """


    kwargs = _get_kwargs(
        org=org,
repo=repo,
base=base,
head=head,

    )

    response = await client.get_async_httpx_client().request(
        **kwargs
    )

    return _build_response(client=client, response=response)

async def asyncio(
    org: str,
    repo: str,
    *,
    client: AuthenticatedClient | Client,
    base: str,
    head: str,

) -> GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500 | None:
    """ Get diff

     Retrieve the diff between two commit OIDs

    Args:
        org (str):
        repo (str):
        base (str):
        head (str):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        GetByOrgByRepoDiffResponse200 | GetByOrgByRepoDiffResponse400 | GetByOrgByRepoDiffResponse401 | GetByOrgByRepoDiffResponse403 | GetByOrgByRepoDiffResponse404 | GetByOrgByRepoDiffResponse406 | GetByOrgByRepoDiffResponse409 | GetByOrgByRepoDiffResponse500
     """


    return (await asyncio_detailed(
        org=org,
repo=repo,
client=client,
base=base,
head=head,

    )).parsed



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from dateutil.parser import isoparse
from typing import cast
import datetime

if TYPE_CHECKING:
  from ..models.get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0 import GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0





T = TypeVar("T", bound="GetByOrgRepoResponse200ReposItemUpstreamType0")



@_attrs_define
class GetByOrgRepoResponse200ReposItemUpstreamType0:
    """ 
        Attributes:
            uri (str): URL of the upstream repository
            autosync (GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0 | None): Automatic sync configuration, if
                enabled
            last_sync_attempt (datetime.datetime | None): Timestamp of the last sync attempt
            last_sync_success (datetime.datetime | None): Timestamp of the last successful sync
            last_sync_error (None | str): Error message from the last failed sync attempt
            has_credential (bool): Whether this upstream has an authentication credential configured
            credential_host (None | str): The host the credential is scoped to (e.g. "github.com")
     """

    uri: str
    autosync: GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0 | None
    last_sync_attempt: datetime.datetime | None
    last_sync_success: datetime.datetime | None
    last_sync_error: None | str
    has_credential: bool
    credential_host: None | str
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0 import GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0
        uri = self.uri

        autosync: dict[str, Any] | None
        if isinstance(self.autosync, GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0):
            autosync = self.autosync.to_dict()
        else:
            autosync = self.autosync

        last_sync_attempt: None | str
        if isinstance(self.last_sync_attempt, datetime.datetime):
            last_sync_attempt = self.last_sync_attempt.isoformat()
        else:
            last_sync_attempt = self.last_sync_attempt

        last_sync_success: None | str
        if isinstance(self.last_sync_success, datetime.datetime):
            last_sync_success = self.last_sync_success.isoformat()
        else:
            last_sync_success = self.last_sync_success

        last_sync_error: None | str
        last_sync_error = self.last_sync_error

        has_credential = self.has_credential

        credential_host: None | str
        credential_host = self.credential_host


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "uri": uri,
            "autosync": autosync,
            "last_sync_attempt": last_sync_attempt,
            "last_sync_success": last_sync_success,
            "last_sync_error": last_sync_error,
            "has_credential": has_credential,
            "credential_host": credential_host,
        })

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_by_org_repo_response_200_repos_item_upstream_type_0_autosync_type_0 import GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0
        d = dict(src_dict)
        uri = d.pop("uri")

        def _parse_autosync(data: object) -> GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0 | None:
            if data is None:
                return data
            try:
                if not isinstance(data, dict):
                    raise TypeError()
                autosync_type_0 = GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0.from_dict(data)



                return autosync_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(GetByOrgRepoResponse200ReposItemUpstreamType0AutosyncType0 | None, data)

        autosync = _parse_autosync(d.pop("autosync"))


        def _parse_last_sync_attempt(data: object) -> datetime.datetime | None:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                last_sync_attempt_type_0 = isoparse(data)



                return last_sync_attempt_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None, data)

        last_sync_attempt = _parse_last_sync_attempt(d.pop("last_sync_attempt"))


        def _parse_last_sync_success(data: object) -> datetime.datetime | None:
            if data is None:
                return data
            try:
                if not isinstance(data, str):
                    raise TypeError()
                last_sync_success_type_0 = isoparse(data)



                return last_sync_success_type_0
            except (TypeError, ValueError, AttributeError, KeyError):
                pass
            return cast(datetime.datetime | None, data)

        last_sync_success = _parse_last_sync_success(d.pop("last_sync_success"))


        def _parse_last_sync_error(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        last_sync_error = _parse_last_sync_error(d.pop("last_sync_error"))


        has_credential = d.pop("has_credential")

        def _parse_credential_host(data: object) -> None | str:
            if data is None:
                return data
            return cast(None | str, data)

        credential_host = _parse_credential_host(d.pop("credential_host"))


        get_by_org_repo_response_200_repos_item_upstream_type_0 = cls(
            uri=uri,
            autosync=autosync,
            last_sync_attempt=last_sync_attempt,
            last_sync_success=last_sync_success,
            last_sync_error=last_sync_error,
            has_credential=has_credential,
            credential_host=credential_host,
        )


        get_by_org_repo_response_200_repos_item_upstream_type_0.additional_properties = d
        return get_by_org_repo_response_200_repos_item_upstream_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..models.post_by_org_by_repo_commit_body_files_item_type_0_encoding import PostByOrgByRepoCommitBodyFilesItemType0Encoding
from ..models.post_by_org_by_repo_commit_body_files_item_type_0_mode import PostByOrgByRepoCommitBodyFilesItemType0Mode
from ..types import UNSET, Unset
from typing import Literal, cast






T = TypeVar("T", bound="PostByOrgByRepoCommitBodyFilesItemType0")



@_attrs_define
class PostByOrgByRepoCommitBodyFilesItemType0:
    """ 
        Attributes:
            path (str):
            content (str):
            encoding (PostByOrgByRepoCommitBodyFilesItemType0Encoding | Unset):  Default:
                PostByOrgByRepoCommitBodyFilesItemType0Encoding.UTF_8.
            action (Literal['upsert'] | Unset):
            mode (PostByOrgByRepoCommitBodyFilesItemType0Mode | Unset):
     """

    path: str
    content: str
    encoding: PostByOrgByRepoCommitBodyFilesItemType0Encoding | Unset = PostByOrgByRepoCommitBodyFilesItemType0Encoding.UTF_8
    action: Literal['upsert'] | Unset = UNSET
    mode: PostByOrgByRepoCommitBodyFilesItemType0Mode | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        path = self.path

        content = self.content

        encoding: str | Unset = UNSET
        if not isinstance(self.encoding, Unset):
            encoding = self.encoding.value


        action = self.action

        mode: str | Unset = UNSET
        if not isinstance(self.mode, Unset):
            mode = self.mode.value



        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "path": path,
            "content": content,
        })
        if encoding is not UNSET:
            field_dict["encoding"] = encoding
        if action is not UNSET:
            field_dict["action"] = action
        if mode is not UNSET:
            field_dict["mode"] = mode

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        d = dict(src_dict)
        path = d.pop("path")

        content = d.pop("content")

        _encoding = d.pop("encoding", UNSET)
        encoding: PostByOrgByRepoCommitBodyFilesItemType0Encoding | Unset
        if isinstance(_encoding,  Unset):
            encoding = UNSET
        else:
            encoding = PostByOrgByRepoCommitBodyFilesItemType0Encoding(_encoding)




        action = cast(Literal['upsert'] | Unset , d.pop("action", UNSET))
        if action != 'upsert'and not isinstance(action, Unset):
            raise ValueError(f"action must match const 'upsert', got '{action}'")

        _mode = d.pop("mode", UNSET)
        mode: PostByOrgByRepoCommitBodyFilesItemType0Mode | Unset
        if isinstance(_mode,  Unset):
            mode = UNSET
        else:
            mode = PostByOrgByRepoCommitBodyFilesItemType0Mode(_mode)




        post_by_org_by_repo_commit_body_files_item_type_0 = cls(
            path=path,
            content=content,
            encoding=encoding,
            action=action,
            mode=mode,
        )


        post_by_org_by_repo_commit_body_files_item_type_0.additional_properties = d
        return post_by_org_by_repo_commit_body_files_item_type_0

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from ..types import UNSET, Unset
from typing import cast

if TYPE_CHECKING:
  from ..models.post_by_org_repo_body_tags import PostByOrgRepoBodyTags
  from ..models.post_by_org_repo_body_upstream import PostByOrgRepoBodyUpstream





T = TypeVar("T", bound="PostByOrgRepoBody")



@_attrs_define
class PostByOrgRepoBody:
    """ 
        Attributes:
            name (str):
            default_branch (str | Unset):  Default: 'main'.
            tags (PostByOrgRepoBodyTags | Unset):
            upstream (PostByOrgRepoBodyUpstream | Unset):
     """

    name: str
    default_branch: str | Unset = 'main'
    tags: PostByOrgRepoBodyTags | Unset = UNSET
    upstream: PostByOrgRepoBodyUpstream | Unset = UNSET
    additional_properties: dict[str, Any] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.post_by_org_repo_body_tags import PostByOrgRepoBodyTags
        from ..models.post_by_org_repo_body_upstream import PostByOrgRepoBodyUpstream
        name = self.name

        default_branch = self.default_branch

        tags: dict[str, Any] | Unset = UNSET
        if not isinstance(self.tags, Unset):
            tags = self.tags.to_dict()

        upstream: dict[str, Any] | Unset = UNSET
        if not isinstance(self.upstream, Unset):
            upstream = self.upstream.to_dict()


        field_dict: dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "name": name,
        })
        if default_branch is not UNSET:
            field_dict["default_branch"] = default_branch
        if tags is not UNSET:
            field_dict["tags"] = tags
        if upstream is not UNSET:
            field_dict["upstream"] = upstream

        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.post_by_org_repo_body_tags import PostByOrgRepoBodyTags
        from ..models.post_by_org_repo_body_upstream import PostByOrgRepoBodyUpstream
        d = dict(src_dict)
        name = d.pop("name")

        default_branch = d.pop("default_branch", UNSET)

        _tags = d.pop("tags", UNSET)
        tags: PostByOrgRepoBodyTags | Unset
        if isinstance(_tags,  Unset):
            tags = UNSET
        else:
            tags = PostByOrgRepoBodyTags.from_dict(_tags)




        _upstream = d.pop("upstream", UNSET)
        upstream: PostByOrgRepoBodyUpstream | Unset
        if isinstance(_upstream,  Unset):
            upstream = UNSET
        else:
            upstream = PostByOrgRepoBodyUpstream.from_dict(_upstream)




        post_by_org_repo_body = cls(
            name=name,
            default_branch=default_branch,
            tags=tags,
            upstream=upstream,
        )


        post_by_org_repo_body.additional_properties = d
        return post_by_org_repo_body

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from __future__ import annotations

from collections.abc import Mapping
from typing import Any, TypeVar, BinaryIO, TextIO, TYPE_CHECKING, Generator

from attrs import define as _attrs_define
from attrs import field as _attrs_field

from ..types import UNSET, Unset

from typing import cast

if TYPE_CHECKING:
  from ..models.get_by_org_repo_tags_response_200_tags_additional_property_item import GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem





T = TypeVar("T", bound="GetByOrgRepoTagsResponse200Tags")



@_attrs_define
class GetByOrgRepoTagsResponse200Tags:
    """ 
     """

    additional_properties: dict[str, list[GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem]] = _attrs_field(init=False, factory=dict)





    def to_dict(self) -> dict[str, Any]:
        from ..models.get_by_org_repo_tags_response_200_tags_additional_property_item import GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem
        
        field_dict: dict[str, Any] = {}
        for prop_name, prop in self.additional_properties.items():
            field_dict[prop_name] = []
            for additional_property_item_data in prop:
                additional_property_item = additional_property_item_data.to_dict()
                field_dict[prop_name].append(additional_property_item)




        return field_dict



    @classmethod
    def from_dict(cls: type[T], src_dict: Mapping[str, Any]) -> T:
        from ..models.get_by_org_repo_tags_response_200_tags_additional_property_item import GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem
        d = dict(src_dict)
        get_by_org_repo_tags_response_200_tags = cls(
        )


        additional_properties = {}
        for prop_name, prop_dict in d.items():
            additional_property = []
            _additional_property = prop_dict
            for additional_property_item_data in (_additional_property):
                additional_property_item = GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem.from_dict(additional_property_item_data)



                additional_property.append(additional_property_item)

            additional_properties[prop_name] = additional_property

        get_by_org_repo_tags_response_200_tags.additional_properties = additional_properties
        return get_by_org_repo_tags_response_200_tags

    @property
    def additional_keys(self) -> list[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> list[GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem]:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: list[GetByOrgRepoTagsResponse200TagsAdditionalPropertyItem]) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum

class PostByOrgApiKeyBodyScopesItem(str, Enum):
    ADMIN = "admin"
    GITREAD = "git:read"
    GITWRITE = "git:write"
    REPOCREATE = "repo:create"
    REPODELETE = "repo:delete"
    REPOREAD = "repo:read"
    WEBHOOKREAD = "webhook:read"
    WEBHOOKWRITE = "webhook:write"

    def __str__(self) -> str:
        return str(self.value)
